[evolution/wip/gsettings: 13/15] Migrate EMailAttachmentBar to GSettings



commit 004eb21e79a68f50cf08a2cb1b005db8b4b20189
Author: Rodrigo Moya <rodrigo gnome-db org>
Date:   Fri Oct 14 13:50:43 2011 +0200

    Migrate EMailAttachmentBar to GSettings

 mail/e-mail-attachment-bar.c |   14 +++++---------
 1 files changed, 5 insertions(+), 9 deletions(-)
---
diff --git a/mail/e-mail-attachment-bar.c b/mail/e-mail-attachment-bar.c
index 17a7ae1..f3567f2 100644
--- a/mail/e-mail-attachment-bar.c
+++ b/mail/e-mail-attachment-bar.c
@@ -27,8 +27,6 @@
 
 #include <glib/gi18n.h>
 
-#include "e-util/gconf-bridge.h"
-
 #include "e-attachment-store.h"
 #include "e-attachment-icon-view.h"
 #include "e-attachment-tree-view.h"
@@ -257,13 +255,11 @@ static void
 mail_attachment_bar_constructed (GObject *object)
 {
 	EMailAttachmentBarPrivate *priv;
-	GConfBridge *bridge;
+	GSettings *settings;
 	const gchar *key;
 
 	priv = E_MAIL_ATTACHMENT_BAR (object)->priv;
 
-	bridge = gconf_bridge_get ();
-
 	/* Set up property-to-property bindings. */
 
 	g_object_bind_property (
@@ -314,10 +310,10 @@ mail_attachment_bar_constructed (GObject *object)
 		G_BINDING_BIDIRECTIONAL |
 		G_BINDING_SYNC_CREATE);
 
-	/* Set up property-to-GConf bindings. */
-
-	key = "/apps/evolution/shell/attachment_view";
-	gconf_bridge_bind_property (bridge, key, object, "active-view");
+	/* Set up property-to-GSettings bindings. */
+	settings = g_settings_new ("org.gnome.evolution.shell");
+	g_settings_bind (settings, "attachment-view", object, "active-view", G_SETTINGS_BIND_DEFAULT);
+	g_object_unref (settings);
 
 	/* Chain up to parent's constructed() method. */
 	G_OBJECT_CLASS (parent_class)->constructed (object);



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]